==> zio-aws-xray_2.13-5.17.130.6-sources.jar: zio/aws/xray/model/ServiceId.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ServiceId(
    name: Option[String] = None,
    names: Option[Iterable[String]] = None,
    accountId: Option[String] = None,
    `type`: Option[String] = None
) {
  def buildAwsValue(): software.amazon.awssdk.services.xray.model.ServiceId = {
    import ServiceId.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.ServiceId
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        names.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.names)
      .optionallyWith(accountId.map(value => value: java.lang.String))(
        _.accountId
      )
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.xray.model.ServiceId.ReadOnly =
    zio.aws.xray.model.ServiceId.wrap(buildAwsValue())
}
object ServiceId {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.xray.model.ServiceId] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.ServiceId = zio.aws.xray.model.ServiceId(
      name.map(value => value),
      names.map(value => value),
      accountId.map(value => value),
      `type`.map(value => value)
    )
    def name: Option[String]
    def names: Option[List[String]]
    def accountId: Option[String]
    def `type`: Option[String]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("names", names)
    def getAccountId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.ServiceId
  ) extends zio.aws.xray.model.ServiceId.ReadOnly {
    override val name: Option[String] =
      scala.Option(impl.name()).map(value => value: String)
    override val names: Option[List[String]] = scala
      .Option(impl.names())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val accountId: Option[String] =
      scala.Option(impl.accountId()).map(value => value: String)
    override val `type`: Option[String] =
      scala.Option(impl.`type`()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.ServiceId
  ): zio.aws.xray.model.ServiceId.ReadOnly = new Wrapper(impl)
}

==> zio-aws-xray_2.13-5.17.167.1-sources.jar: zio/aws/xray/model/ServiceId.scala <==
package zio.aws.xray.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ServiceId(
    name: Optional[String] = Optional.Absent,
    names: Optional[Iterable[String]] = Optional.Absent,
    accountId: Optional[String] = Optional.Absent,
    `type`: Optional[String] = Optional.Absent
) {
  def buildAwsValue(): software.amazon.awssdk.services.xray.model.ServiceId = {
    import ServiceId.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.xray.model.ServiceId
      .builder()
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(
        names.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.names)
      .optionallyWith(accountId.map(value => value: java.lang.String))(
        _.accountId
      )
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.xray.model.ServiceId.ReadOnly =
    zio.aws.xray.model.ServiceId.wrap(buildAwsValue())
}
object ServiceId {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.xray.model.ServiceId] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.xray.model.ServiceId = zio.aws.xray.model.ServiceId(
      name.map(value => value),
      names.map(value => value),
      accountId.map(value => value),
      `type`.map(value => value)
    )
    def name: Optional[String]
    def names: Optional[List[String]]
    def accountId: Optional[String]
    def `type`: Optional[String]
    def getName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("name", name)
    def getNames: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("names", names)
    def getAccountId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getType: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.xray.model.ServiceId
  ) extends zio.aws.xray.model.ServiceId.ReadOnly {
    override val name: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => value: String)
    override val names: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.names())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
    override val accountId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.accountId())
      .map(value => value: String)
    override val `type`: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.xray.model.ServiceId
  ): zio.aws.xray.model.ServiceId.ReadOnly = new Wrapper(impl)
}
